@@ -12,7 +12,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: ipsec_esp.h,v 1.1.2.1 2004/03/21 05:23:30 mcr Exp $
+ * RCSID $Id: ipsec_esp.h,v 1.25 2004/04/06 02:49:08 mcr Exp $
  */
 
 #include "openswan/ipsec_md5h.h"
@@ -24,6 +24,8 @@
 #define IPPROTO_ESP 50
 #endif /* IPPROTO_ESP */
 
+#define ESP_HEADER_LEN		8	/* 64 bits header (spi+rpl)*/
+
 #define EMT_ESPDESCBC_ULEN	20	/* coming from user mode */
 #define EMT_ESPDES_KMAX		64	/* 512 bit secret key enough? */
 #define EMT_ESPDES_KEY_SZ	8	/* 56 bit secret key with parity = 64 bits */
@@ -31,6 +33,9 @@
 #define EMT_ESPDES_IV_SZ	8	/* IV size */
 #define ESP_DESCBC_BLKLEN       8       /* DES-CBC block size */
 
+#define ESP_IV_MAXSZ		16	/* This is _critical_ */
+#define ESP_IV_MAXSZ_INT	(ESP_IV_MAXSZ/sizeof(int))
+
 #define DB_ES_PKTRX	0x0001
 #define DB_ES_PKTRX2	0x0002
 #define DB_ES_IPSA	0x0010
@@ -67,11 +72,14 @@ extern int debug_esp;
 
 /*
  * $Log: ipsec_esp.h,v $
- * Revision 1.1.2.1  2004/03/21 05:23:30  mcr
- *     pullup of freeswan->openswan and CR/CERT patches from HEAD
+ * Revision 1.25  2004/04/06 02:49:08  mcr
+ * 	pullup of algo code from alg-branch.
  *
- * Revision 1.1  2004/03/08 01:44:10  ken
- * Import from ../freeswan/
+ * Revision 1.24  2004/04/05 19:55:05  mcr
+ * Moved from linux/include/freeswan/ipsec_esp.h,v
+ *
+ * Revision 1.23  2004/04/05 19:41:05  mcr
+ * 	merged alg-branch code.
  *
  * Revision 1.22  2003/12/13 19:10:16  mcr
  * 	refactored rcv and xmit code - same as FS 2.05.
@@ -87,6 +95,9 @@ extern int debug_esp;
  * 	split up receive path into per-transform files, for
  * 	easier later removal.
  *
+ * Revision 1.21.8.1  2003/12/22 15:25:52  jjo
+ *      Merged algo-0.8.1-rc11-test1 into alg-branch
+ *
  * Revision 1.21  2003/02/06 02:21:34  rgb
  *
  * Moved "struct auth_alg" from ipsec_rcv.c to ipsec_ah.h .
@@ -132,86 +143,5 @@ extern int debug_esp;
  * Revision 1.11  2000/01/10 16:36:20  rgb
  * Ditch last of EME option flags, including initiator.
  *
- * Revision 1.10  1999/12/07 18:16:22  rgb
- * Fixed comments at end of #endif lines.
- *
- * Revision 1.9  1999/04/11 00:28:57  henry
- * GPL boilerplate
- *
- * Revision 1.8  1999/04/06 04:54:25  rgb
- * Fix/Add RCSID Id: and Log: bits to make PHMDs happy.  This includes
- * patch shell fixes.
- *
- * Revision 1.7  1999/01/26 02:06:00  rgb
- * Removed CONFIG_IPSEC_ALGO_SWITCH macro.
- *
- * Revision 1.6  1999/01/22 15:22:05  rgb
- * Re-enable IV in the espblkrply_edata structure to avoid breaking pluto
- * until pluto can be fixed properly.
- *
- * Revision 1.5  1999/01/22 06:18:16  rgb
- * Updated macro comments.
- * Added key schedule types to support algorithm switch code.
- *
- * Revision 1.4  1998/08/12 00:07:32  rgb
- * Added data structures for new xforms: null, {,3}dessha1.
- *
- * Revision 1.3  1998/07/14 15:57:01  rgb
- * Add #ifdef __KERNEL__ to protect kernel-only structures.
- *
- * Revision 1.2  1998/06/25 19:33:46  rgb
- * Add prototype for protocol receive function.
- * Rearrange for more logical layout.
- *
- * Revision 1.1  1998/06/18 21:27:45  henry
- * move sources from klips/src to klips/net/ipsec, to keep stupid
- * kernel-build scripts happier in the presence of symlinks
- *
- * Revision 1.6  1998/06/05 02:28:08  rgb
- * Minor comment fix.
- *
- * Revision 1.5  1998/05/27 22:34:00  rgb
- * Changed structures to accomodate key separation.
- *
- * Revision 1.4  1998/05/18 22:28:43  rgb
- * Disable key printing facilities from /proc/net/ipsec_*.
- *
- * Revision 1.3  1998/04/21 21:29:07  rgb
- * Rearrange debug switches to change on the fly debug output from user
- * space.  Only kernel changes checked in at this time.  radij.c was also
- * changed to temporarily remove buggy debugging code in rj_delete causing
- * an OOPS and hence, netlink device open errors.
- *
- * Revision 1.2  1998/04/12 22:03:20  rgb
- * Updated ESP-3DES-HMAC-MD5-96,
- * 	ESP-DES-HMAC-MD5-96,
- * 	AH-HMAC-MD5-96,
- * 	AH-HMAC-SHA1-96 since Henry started freeswan cvs repository
- * from old standards (RFC182[5-9] to new (as of March 1998) drafts.
- *
- * Fixed eroute references in /proc/net/ipsec*.
- *
- * Started to patch module unloading memory leaks in ipsec_netlink and
- * radij tree unloading.
- *
- * Revision 1.1  1998/04/09 03:06:00  henry
- * sources moved up from linux/net/ipsec
- *
- * Revision 1.1.1.1  1998/04/08 05:35:02  henry
- * RGB's ipsec-0.8pre2.tar.gz ipsec-0.8
- *
- * Revision 0.5  1997/06/03 04:24:48  ji
- * Added ESP-3DES-MD5-96 transform.
- *
- * Revision 0.4  1997/01/15 01:28:15  ji
- * Added definitions for new ESP transforms.
- *
- * Revision 0.3  1996/11/20 14:35:48  ji
- * Minor Cleanup.
- * Rationalized debugging code.
- *
- * Revision 0.2  1996/11/02 00:18:33  ji
- * First limited release.
- *
  *
  */
