@@ -13,7 +13,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: ipsec_radij.h,v 1.1.2.1 2004/03/21 05:23:31 mcr Exp $
+ * RCSID $Id: ipsec_radij.h,v 1.21 2004/04/29 11:06:42 ken Exp $
  */
 
 #ifndef _IPSEC_RADIJ_H
@@ -25,15 +25,19 @@ int ipsec_walk(char *);
 int ipsec_rj_walker_procprint(struct radij_node *, void *);
 int ipsec_rj_walker_delete(struct radij_node *, void *);
 
+/* This structure is used to pass information between
+ * ipsec_eroute_get_info and ipsec_rj_walker_procprint
+ * (through rj_walktree) and between calls of ipsec_rj_walker_procprint.
+ */
 struct wsbuf
 {
-	char *buffer;
-	int length;
-	off_t offset;
-	int len;
-	int prev_len;
-	off_t begin;
-	off_t pos;
+       /* from caller of ipsec_eroute_get_info: */
+       char *const buffer;     /* start of buffer provided */
+       const int length;       /* length of buffer provided */
+       const off_t offset;     /* file position of first character of interest */
+       /* accumulated by ipsec_rj_walker_procprint: */
+       int len;        /* number of character filled into buffer */
+       off_t begin;    /* file position contained in buffer[0] (<=offset) */
 };
 
 extern struct radij_node_head *rnh;
@@ -59,11 +63,14 @@ void rj_dumptrees(void);
 
 /*
  * $Log: ipsec_radij.h,v $
- * Revision 1.1.2.1  2004/03/21 05:23:31  mcr
- *     pullup of freeswan->openswan and CR/CERT patches from HEAD
+ * Revision 1.21  2004/04/29 11:06:42  ken
+ * Last bits from 2.06 procfs updates
  *
- * Revision 1.1  2004/03/08 01:44:10  ken
- * Import from ../freeswan/
+ * Revision 1.20  2004/04/06 02:49:08  mcr
+ * 	pullup of algo code from alg-branch.
+ *
+ * Revision 1.19  2004/04/05 19:55:06  mcr
+ * Moved from linux/include/freeswan/ipsec_radij.h,v
  *
  * Revision 1.18  2002/04/24 07:36:47  mcr
  * Moved from ./klips/net/ipsec/ipsec_radij.h,v
