@@ -13,7 +13,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: ipsec_rcv.h,v 1.1.2.1 2004/03/21 05:23:31 mcr Exp $
+ * RCSID $Id: ipsec_rcv.h,v 1.21 2004/04/06 02:49:08 mcr Exp $
  */
 
 #ifndef IPSEC_RCV_H
@@ -70,7 +70,8 @@ enum ipsec_rcv_value {
 	IPSEC_RCV_BADAUTH=-14,
 	IPSEC_RCV_REPLAYFAILED=-15,
 	IPSEC_RCV_AUTHFAILED=-16,
-	IPSEC_RCV_REPLAYROLLED=-17
+	IPSEC_RCV_REPLAYROLLED=-17,
+	IPSEC_RCV_BAD_DECRYPT=-18
 };
 
 struct ipsec_rcv_state {
@@ -144,11 +145,11 @@ extern int sysctl_ipsec_inbound_policy_check;
 
 /*
  * $Log: ipsec_rcv.h,v $
- * Revision 1.1.2.1  2004/03/21 05:23:31  mcr
- *     pullup of freeswan->openswan and CR/CERT patches from HEAD
+ * Revision 1.21  2004/04/06 02:49:08  mcr
+ * 	pullup of algo code from alg-branch.
  *
- * Revision 1.1  2004/03/08 01:44:10  ken
- * Import from ../freeswan/
+ * Revision 1.20  2004/04/05 19:55:06  mcr
+ * Moved from linux/include/freeswan/ipsec_rcv.h,v
  *
  * Revision 1.19  2003/12/15 18:13:09  mcr
  * 	when compiling with NAT traversal, don't assume that the
