@@ -13,10 +13,10 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: ipsec_xmit.h,v 1.1.2.1 2004/03/21 05:23:31 mcr Exp $
+ * RCSID $Id: ipsec_xmit.h,v 1.9 2004/04/06 02:49:08 mcr Exp $
  */
 
-#include "freeswan/ipsec_sa.h"
+#include "openswan/ipsec_sa.h"
 
 enum ipsec_xmit_value
 {
@@ -139,11 +139,11 @@ extern int sysctl_ipsec_tos;
 
 /*
  * $Log: ipsec_xmit.h,v $
- * Revision 1.1.2.1  2004/03/21 05:23:31  mcr
- *     pullup of freeswan->openswan and CR/CERT patches from HEAD
+ * Revision 1.9  2004/04/06 02:49:08  mcr
+ * 	pullup of algo code from alg-branch.
  *
- * Revision 1.1  2004/03/08 01:44:10  ken
- * Import from ../freeswan/
+ * Revision 1.8  2004/04/05 19:55:07  mcr
+ * Moved from linux/include/freeswan/ipsec_xmit.h,v
  *
  * Revision 1.7  2004/02/03 03:11:40  mcr
  * 	new xmit type if the UDP encapsulation is wrong.
