@@ -11,7 +11,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: ipsec_doi.h,v 1.32 2003/12/10 01:58:06 mcr Exp $
+ * RCSID $Id: ipsec_doi.h,v 1.35 2004/06/14 01:46:02 mcr Exp $
  */
 
 extern void echo_hdr(struct msg_digest *md, bool enc, u_int8_t np);
@@ -37,6 +37,9 @@ extern state_transition_fn
     main_inR2_outI3,
     main_inI3_outR3,
     main_inR3,
+    aggr_inI1_outR1,
+    aggr_inR1_outI2,
+    aggr_inI2,
     quick_inI1_outR1,
     quick_inR1_outI2,
     quick_inI2;
@@ -45,6 +48,9 @@ extern void send_delete(struct state *st);
 extern void accept_delete(struct state *st, struct msg_digest *md
     , struct payload_digest *p);
 
+extern void send_notification_from_state(struct state *st,
+    enum state_kind state, u_int16_t type);
+extern void send_notification_from_md(struct msg_digest *md, u_int16_t type);
 
 extern const char *init_pluto_vendorid(void);
 
@@ -54,6 +60,13 @@ extern const char *init_pluto_vendorid(void);
 extern void close_message(pb_stream *pbs); /* forward declaration */
 extern bool encrypt_message(pb_stream *pbs, struct state *st); /* forward declaration */
 
+extern void dpd_outI(struct state *st);
+extern stf_status dpd_inI_outR(struct state *st
+            , struct isakmp_notification *const n, pb_stream *n_pbs);
+extern stf_status dpd_inR(struct state *st
+            , struct isakmp_notification *const n, pb_stream *n_pbs);
+extern void dpd_timeout(struct state *st);
+
 /* START_HASH_PAYLOAD
  *
  * Emit a to-be-filled-in hash payload, noting the field start (r_hashval)
