@@ -12,11 +12,13 @@ REF_WEST_OUTPUT=../../klips/outputs/westnet-null.txt
 WEST_ARPREPLY=true
 
 REF_PUB_OUTPUT=../../klips/outputs/publicnet-west-east-ping.txt
-REF_PUB_FILTER=../../klips/fixups/no-arp-pcap.pl
-PUBLIC_ARPREPLY=true
+REF_PUB_FILTER=../../klips/fixups/no-arp-pcap2.pl
+#PUBLIC_ARPREPLY=true
 
 REF_EAST_CONSOLE_OUTPUT=east-console.txt
 
+THREEEIGHT=true
+
 REF_CONSOLE_FIXUPS="kern-list-fixups.sed nocr.sed"
 REF_CONSOLE_FIXUPS="$REF_CONSOLE_FIXUPS ipsec-look-esp-sanitize.pl"
 REF_CONSOLE_FIXUPS="$REF_CONSOLE_FIXUPS east-prompt-splitline.pl"
