@@ -16,11 +16,13 @@ REF_CONSOLE_FIXUPS="$REF_CONSOLE_FIXUPS pluto-whack-sanitize.sed"
 
 EASTHOST=east
 EAST_INIT_SCRIPT=eastinit.sh
+EAST_FINAL_SCRIPT=final.sh
 REF_EAST_CONSOLE_OUTPUT=east-console.txt
 
 ROADHOST=road
 ROAD_INIT_SCRIPT=roadinit.sh
 ROAD_RUN_SCRIPT=roadrun.sh
+ROAD_FINAL_SCRIPT=final.sh
 REF_ROAD_CONSOLE_OUTPUT=road-console.txt
 
 ADDITIONAL_HOSTS="nic"
