@@ -1,7 +1,7 @@
 #!/bin/sh
 
 #
-# $Id: functions.sh,v 1.103 2004/02/16 04:13:37 mcr Exp $
+# $Id: functions.sh,v 1.108 2004/05/19 14:53:31 mcr Exp $
 #
 
 preptest() {
@@ -210,6 +210,8 @@ prerunsetup() {
 
     # export variables that are common.
     export PACKETRATE
+
+    perl ${OPENSWANSRCDIR}/testing/utils/regress-summarize-results.pl ${REGRESSRESULTS} ${TESTNAME}
 }
 
 
@@ -330,7 +332,7 @@ roguekill() {
     if [ -n "$other_rogues" ]
     then
 	echo "ROGUES without brand $UML_BRAND:"
-	ps -f -p -w $other_rogues
+	ps -f -w -p $other_rogues
     fi
     stat="$stat$rogue_sighted"
 }
@@ -468,7 +470,11 @@ pcap_filter() {
 	FILTER=cat
     fi
 
-    FILTER="$FILTER | sed -f $FIXUPDIR/tcpdump-three-eight.sed"
+    # refilter 3.8 output for 3.7 files unless the case has been updated
+    if [ -z "$THREEEIGHT" ] && $THREEEIGHT
+    then
+	FILTER="$FILTER | sed -f $FIXUPDIR/tcpdump-three-eight.sed"
+    fi
 
     if [ -n "$OUTPUT" ]
     then
@@ -695,31 +701,31 @@ do_make_install_test() {
     if [ -n "$INSTALL_FLAGS" ]
     then
 	$MAKE_INSTALL_TEST_DEBUG && echo make --no-print-directory DESTDIR=$instdir $INSTALL_FLAGS
-	(cd $FREESWANSRCDIR && eval make FREESWANSRCDIR=`pwd` --no-print-directory DESTDIR=$instdir $INSTALL_FLAGS ) >OUTPUT${KLIPS_MODULE}/install1.txt 2>&1 || exit 1
+	(cd $OPENSWANSRCDIR && eval make OPENSWANSRCDIR=`pwd` --no-print-directory DESTDIR=$instdir $INSTALL_FLAGS ) >OUTPUT${KLIPS_MODULE}/install1.txt 2>&1 || exit 1
     fi
 
     if [ -n "$POSTINSTALL_SCRIPT" ]
     then
-	$POSTINSTALL_SCRIPT $FREESWANSRCDIR $instdir || exit 1
+	$POSTINSTALL_SCRIPT $OPENSWANSRCDIR $instdir || exit 1
     fi
 
     if [ -n "$INSTALL2_FLAGS" ]
     then
 	$MAKE_INSTALL_TEST_DEBUG && echo make --no-print-directory DESTDIR=$instdir $INSTALL2_FLAGS
-	(cd $FREESWANSRCDIR && eval make FREESWANSRCDIR=`pwd` --no-print-directory DESTDIR=$instdir $INSTALL2_FLAGS ) >OUTPUT${KLIPS_MODULE}/install2.txt 2>&1 || exit 1
+	(cd $OPENSWANSRCDIR && eval make OPENSWANSRCDIR=`pwd` --no-print-directory DESTDIR=$instdir $INSTALL2_FLAGS ) >OUTPUT${KLIPS_MODULE}/install2.txt 2>&1 || exit 1
     fi
 
     if [ -n "$UNINSTALL_FLAGS" ]
     then
 	$MAKE_INSTALL_TEST_DEBUG && echo make --no-print-directory DESTDIR=$instdir $UNINSTALL_FLAGS
-	(cd $FREESWANSRCDIR && eval make FREESWANSRCDIR=`pwd` --no-print-directory DESTDIR=$instdir $UNINSTALL_FLAGS ) >OUTPUT${KLIPS_MODULE}/uninstall.txt 2>&1 || exit 1
+	(cd $OPENSWANSRCDIR && eval make OPENSWANSRCDIR=`pwd` --no-print-directory DESTDIR=$instdir $UNINSTALL_FLAGS ) >OUTPUT${KLIPS_MODULE}/uninstall.txt 2>&1 || exit 1
     fi
 
     if [ -n "$REF_MAKE_DOC_OUTPUT" ]
     then
       rm -f OUTPUT${KLIPS_MODULE}/$REF_MAKE_DOC_OUTPUT.txt
 
-      (cd $FREESWANSRCDIR/doc && eval make FREESWANSRCDIR=$FREESWANSRCDIR clean --no-print-directory && eval make FREESWANSRCDIR=$FREESWANSRCDIR --no-print-directory ) | sort >OUTPUT${KLIPS_MODULE}/$REF_MAKE_DOC_OUTPUT.txt
+      (cd $OPENSWANSRCDIR/doc && eval make OPENSWANSRCDIR=$OPENSWANSRCDIR clean --no-print-directory && eval make OPENSWANSRCDIR=$OPENSWANSRCDIR --no-print-directory ) | sort >OUTPUT${KLIPS_MODULE}/$REF_MAKE_DOC_OUTPUT.txt
       if diff -u -w -b -B $REF_MAKE_DOC_OUTPUT.txt OUTPUT${KLIPS_MODULE}/$REF_MAKE_DOC_OUTPUT.txt >OUTPUT${KLIPS_MODULE}/$REF_MAKE_DOC_OUTPUT.diff
       then
 	 echo "make doc output matched"
@@ -772,7 +778,7 @@ mkinsttest() {
 
     echo '**** Make Install RUNNING' $testdir${KLIPS_MODULE} '****'
 
-    FREESWANSRCDIR=`cd $FREESWANSRCDIR && pwd` export FREESWANSRCDIR
+    OPENSWANSRCDIR=`cd $OPENSWANSRCDIR && pwd` export OPENSWANSRCDIR
 
     export UML_BRAND="$$"
     ( preptest $testdir mkinsttest && do_make_install_test )
@@ -809,11 +815,11 @@ do_rpm_install_test() {
     then
 	echo "Building with kernel source $RPM_KERNEL_SOURCE";
 
-	(cd $FREESWANSRCDIR/packaging/redhat && make clean --no-print-directory && make --no-print-directory RH_KERNELSRC=$RPM_KERNEL_SOURCE FREESWANSRCDIR=$FREESWANSRCDIR rpm )
+	(cd $OPENSWANSRCDIR/packaging/redhat && make clean --no-print-directory && make --no-print-directory RH_KERNELSRC=$RPM_KERNEL_SOURCE OPENSWANSRCDIR=$OPENSWANSRCDIR rpm )
     fi
 
     mkdir OUTPUT${KLIPS_MODULE}/rpm
-    cp $FREESWANSRCDIR/packaging/redhat/rpms/RPMS/i386/*.rpm OUTPUT${KLIPS_MODULE}/rpm
+    cp $OPENSWANSRCDIR/packaging/redhat/rpms/RPMS/i386/*.rpm OUTPUT${KLIPS_MODULE}/rpm
 
     # while loop below winds up in sub-shell. Argh.
     successfile=OUTPUT${KLIPS_MODULE}/success
@@ -861,7 +867,7 @@ rpm_build_install_test() {
 
     echo '**** Make Install RUNNING' $testdir${KLIPS_MODULE} '****'
 
-    FREESWANSRCDIR=`cd $FREESWANSRCDIR && pwd` export FREESWANSRCDIR
+    OPENSWANSRCDIR=`cd $OPENSWANSRCDIR && pwd` export OPENSWANSRCDIR
 
     export UML_BRAND="$$"
     ( preptest $testdir rpm_build_install_test && do_rpm_install_test )
@@ -887,22 +893,48 @@ libtest() {
     testexpect=$2
     testsrc=$testobj.c
 
+    CC=${CC-cc}
+
     echo '**** make libtest RUNNING' $testsrc '****'
 
     symbol=`echo $testobj | tr 'a-z' 'A-Z'`_MAIN
 
-    cc -g -o $testobj -D$symbol -I${LIBFREESWANDIR} -I${FREESWANSRCDIR}/linux/include -I${FREESWANSRCDIR} ${LIBFREESWANDIR}/$testsrc ${FREESWANLIB}
-    rm -rf lib-$testobj/OUTPUT
-    mkdir -p lib-$testobj/OUTPUT
-
-    export TEST_PURPOSE=regress
-
-    ( ./$testobj -r >lib-$testobj/OUTPUT${KLIPS_MODULE}/$testobj.txt )
-
-    stat=$?
-    if [ $stat -gt 128 ]
+    if [ -f ${LIBOPENSWANDIR}/$testsrc ] 
     then
-	stat="$stat core"
+	FILE=${LIBOPENSWANDIR}/$testsrc
+    elif [ -f ${OPENSWANSRCDIR}/lib/libopenwan/$testsrc ]
+    then
+        FILE=${OPENSWANSRCDIR}/lib/libopenswan/$testsrc
+    elif [ -f ${OPENSWANSRCDIR}/linux/net/klips/$testsrc ]
+    then
+        FILE=${OPENSWANSRCDIR}/linux/net/klips/$testsrc
+    elif [ -f ${OPENSWANSRCDIR}/linux/lib/libopenswan/$testsrc ]
+    then
+        FILE=${OPENSWANSRCDIR}/linux/lib/libopenswan/$testsrc
+    elif [ -f ${OPENSWANSRCDIR}/linux/lib/libfreeswan/$testsrc ]
+    then
+        FILE=${OPENSWANSRCDIR}/linux/lib/libfreeswan/$testsrc
+    elif [ -f ${OPENSWANSRCDIR}/linux/net/ipsec/$testsrc ]
+    then
+        FILE=${OPENSWANSRCDIR}/linux/net/ipsec/$testsrc
+    fi
+
+    stat=99
+    if [ -n "$FILE" -a -r "$FILE" ]
+    then
+	    ${CC} -g -o $testobj -D$symbol -I${LIBOPENSWANDIR} -I${OPENSWANSRCDIR}/linux/include -I${OPENSWANSRCDIR} ${FILE} ${OPENSWANLIB}
+	    rm -rf lib-$testobj/OUTPUT
+	    mkdir -p lib-$testobj/OUTPUT
+
+	    export TEST_PURPOSE=regress
+
+	    ( ./$testobj -r >lib-$testobj/OUTPUT${KLIPS_MODULE}/$testobj.txt )
+
+	    stat=$?
+	    if [ $stat -gt 128 ]
+	    then
+		stat="$stat core"
+	    fi
     fi
 
     TEST_PURPOSE=regress  UML_BRAND=0 recordresults lib-$testobj "$testexpect" $stat lib-$testobj
@@ -1000,9 +1032,9 @@ do_kernel_patch_test() {
     # now patch it. (set +x turns off any debugging there might have been)
     set -x
     set -v
-    # the environment variable FREESWANSRCDIR should be correct
-    # but the make macro FREESWANSRCDIR may be relative, and hence wrong
-    (cd ${FREESWANSRCDIR} && make FREESWANSRCDIR=`pwd` kernelpatch${KERNEL_VERSION} ) | tee OUTPUT${KLIPS_MODULE}/patchfile.patch | (cd OUTPUT${KLIPS_MODULE}/$kernel_var_name && patch -p1 2>&1 ) >OUTPUT${KLIPS_MODULE}/patch-output.txt
+    # the environment variable OPENSWANSRCDIR should be correct
+    # but the make macro OPENSWANSRCDIR may be relative, and hence wrong
+    (cd ${OPENSWANSRCDIR} && make OPENSWANSRCDIR=`pwd` kernelpatch${KERNEL_VERSION} ) | tee OUTPUT${KLIPS_MODULE}/patchfile.patch | (cd OUTPUT${KLIPS_MODULE}/$kernel_var_name && patch -p1 2>&1 ) >OUTPUT${KLIPS_MODULE}/patch-output.txt
 
     # compare the patch.
     if [ -n "${REF_PATCH_OUTPUT}" ]
@@ -1149,7 +1181,7 @@ do_module_compile_test() {
 
     rm -f OUTPUT${KLIPS_MODULE}/module/ipsec.o
 
-    cmd="(cd $FREESWANSRCDIR && make KERNELSRC=$KERNEL_SRC MODBUILDDIR=$moddir FREESWANSRCDIR=$FREESWANSRCDIR MODULE_DEFCONFIG=${MODULE_DEFCONFIG} MODULE_DEF_INCLUDE=${MODULE_DEF_INCLUDE} ARCH=${ARCH} SUBARCH=${SUBARCH} module )"
+    cmd="(cd $OPENSWANSRCDIR && make KERNELSRC=$KERNEL_SRC MODBUILDDIR=$moddir OPENSWANSRCDIR=$OPENSWANSRCDIR MODULE_DEFCONFIG=${MODULE_DEFCONFIG} MODULE_DEF_INCLUDE=${MODULE_DEF_INCLUDE} ARCH=${ARCH} SUBARCH=${SUBARCH} module )"
     echo "# run as" >OUTPUT${KLIPS_MODULE}/doit.sh
     echo "$cmd" >>OUTPUT${KLIPS_MODULE}/doit.sh
     . OUTPUT${KLIPS_MODULE}/doit.sh
@@ -1368,9 +1400,25 @@ umlXhost() {
 }
 
 #
-# $Id: functions.sh,v 1.103 2004/02/16 04:13:37 mcr Exp $
+# $Id: functions.sh,v 1.108 2004/05/19 14:53:31 mcr Exp $
 #
 # $Log: functions.sh,v $
+# Revision 1.108  2004/05/19 14:53:31  mcr
+# 	call summarize results just before each test case.
+#
+# Revision 1.107  2004/04/16 19:57:29  mcr
+# 	if THREEEIGHT is set to true, then do not run the
+# 	three-eight filter.
+#
+# Revision 1.106  2004/04/09 18:30:05  mcr
+# 	look in all sorts of places for the library code.
+#
+# Revision 1.105  2004/04/04 03:57:58  ken
+# Change order of options to ps, as newer versions are more strict about order
+#
+# Revision 1.104  2004/04/03 19:44:52  ken
+# FREESWANSRCDIR -> OPENSWANSRCDIR (patch by folken)
+#
 # Revision 1.103  2004/02/16 04:13:37  mcr
 # 	use new NETWORK_ARPREPLY= to decide how/when to answer arp
 # 	requests.
