@@ -2,8 +2,8 @@
 
 BUILDTOP=${MYBOX-/c2/freeswan/freeswan-1.92}
 export BUILDTOP
-FREESWANSRCDIR=$BUILDTOP 
-export FREESWANSRCDIR
+OPENSWANSRCDIR=$BUILDTOP 
+export OPENSWANSRCDIR
 
 . $BUILDTOP/umlsetup.sh
 
