@@ -1,4 +1,4 @@
-# $Id: netjig.tcl,v 1.42.2.1 2004/03/21 05:23:51 mcr Exp $
+# $Id: netjig.tcl,v 1.48 2004/05/05 17:55:20 mcr Exp $
 
 global theprompt
 set theprompt {([a-zA-Z0-9]*):.*# }
@@ -316,6 +316,15 @@ proc runXuml {umlname pass} {
     set_from_env $umlname $scriptname $varname
 
     if {[info exists umlid($umlname,$scriptname)]} {
+	if {[info exists env(UML_GETTY)]} {
+	    send -i $umlid($umlname,spawnid) -- "echo You have 3600 seconds. >/dev/ttys/1\r"
+	    send -i $umlid($umlname,spawnid) -- "echo I would run $umlid($umlname,$scriptname) now >/dev/ttys/1\r"
+	    send -i $umlid($umlname,spawnid) -- "rm /etc/nologin\r"
+	    send -i $umlid($umlname,spawnid) -- "/sbin/getty ttys/1 38400\r"
+	    set timeout 3600
+	    expectprompt $umlid($umlname,spawnid) "UML_getty for $umlname"
+	} 
+
 	if {[file exists $umlid($umlname,$scriptname)]} {
 	    playscript $umlid($umlname,spawnid) $umlid($umlname,$scriptname)
 	    netjigdebug "$umlname run script($pass) $umlid($umlname,$scriptname) done"
@@ -530,11 +539,24 @@ proc process_net {net} {
 
 match_max -d 10000
 
-# $Id: netjig.tcl,v 1.42.2.1 2004/03/21 05:23:51 mcr Exp $
+# $Id: netjig.tcl,v 1.48 2004/05/05 17:55:20 mcr Exp $
 #
 # $Log: netjig.tcl,v $
-# Revision 1.42.2.1  2004/03/21 05:23:51  mcr
-#     pullup of freeswan->openswan and CR/CERT patches from HEAD
+# Revision 1.48  2004/05/05 17:55:20  mcr
+# 	fixed problem with getty not licking multiuser boot.
+#
+# Revision 1.47  2004/05/04 20:05:35  mcr
+# 	use ttys/1 rather than tty1.
+#
+# Revision 1.46  2004/05/04 19:51:46  mcr
+# 	make sure to send \r after each command.
+#
+# Revision 1.45  2004/05/04 19:17:59  mcr
+# 	don't try getty unless we have a run command.
+#
+# Revision 1.44  2004/05/04 18:06:04  mcr
+# 	if UML_GETTY is set, then start a getty before running each
+# 	runuml command.
 #
 # Revision 1.43  2004/03/21 04:36:16  mcr
 # 	1) local switches now reads testparams.sh file.
